@@ -1,11 +1,11 @@
 import os
 
-from typing import List
+from typing import Dict, List
 
 from simple_proxy2.data.proxy_info import ProxyInfo
 
 
-def build_proxy_dict(folder="proxies", txt_file_names=None) -> dict[str, List[str]]:
+def build_proxy_dict(folder="proxies", txt_file_names=None) -> Dict[str, List[str]]:
     """
     Build simple proxy dictionary from the given folder. The folder can contain the following
     files: http.txt, https.txt, socks4.txt, and socks5.txt.
@@ -29,11 +29,12 @@ def build_proxy_dict(folder="proxies", txt_file_names=None) -> dict[str, List[st
 
         with open(path) as f:
             proxy_list = f.readlines()
-        proxy_list_dict[file] = list(map(lambda elem: elem.rstrip('\n'), set(proxy_list)))
+        proxy_list_dict[file] = list(
+            map(lambda elem: elem.rstrip('\n'), set(proxy_list)))
     return proxy_list_dict
 
 
-def proxy_dict_to_info_list(proxy_dict: dict[str, List[str]]) -> List[ProxyInfo]:
+def proxy_dict_to_info_list(proxy_dict: Dict[str, List[str]]) -> List[ProxyInfo]:
     info_set = set()
 
     for protocol, addresses in proxy_dict.items():
