@@ -6,7 +6,7 @@ from threading import Lock, Condition, RLock
 from typing import Dict, List, Callable, Optional, Any
 
 import requests
-from requests import Session
+from requests import Response, Session
 
 from simple_proxy2.data.proxy_info import ProxyInfo
 from simple_proxy2.pool.proxy_pool import ProxyPool
@@ -110,8 +110,9 @@ class ProxyManager:
             else:
                 return self._success / self._trials
 
-    def proxy_as_request_session(self) -> Session:
-        return SessionProxy(self)
+    def proxy_as_request_session(self,
+                                 success_criterion: Callable[[Response], bool] = lambda response: True) -> Session:
+        return SessionProxy(self, success_criterion)
 
     def proxy_session(self,
                       fn: Callable[[Session, tuple], Optional[Any]],
@@ -210,11 +211,12 @@ class ProxyManager:
 
 
 class SessionProxy(Session):
-    def __init__(self, manager: ProxyManager):
+    def __init__(self, manager: ProxyManager, success_criterion):
         super().__init__()
         assert manager._executor_running, "manager hasn't started."
 
         self._manager = manager
+        self._success_criterion = success_criterion
 
     def request(self, method, url,
                 params=None, data=None, headers=None, cookies=None, files=None,
@@ -225,9 +227,15 @@ class SessionProxy(Session):
             if headers is not None:
                 session.headers.update(headers)
 
-            return session.request(method, url,
-                                   params, data, headers, cookies, files,
-                                   auth, timeout, allow_redirects, None,
-                                   hooks, stream, verify, cert, json)
+            response = session.request(method, url,
+                                       params, data, headers, cookies, files,
+                                       auth, timeout, allow_redirects, None,
+                                       hooks, stream, verify, cert, json)
+
+            if not self._success_criterion(response):
+                raise Exception(
+                    "Response does not satisfy the success criterion.")
+
+            return response
 
         return self._manager.proxy_session(fn, wait=True)
